@@ -8,8 +8,8 @@ amh <- function( data , nobs , pars , model ,  prior , proposal_sd ,
 		proposal_refresh = 50 , print_iter = 50 
 					){
 
-		time <- base::list( "start" = Sys.time() )	
-		CALL <- base::match.call()
+		time <- list( "start" = Sys.time() )	
+		CALL <- match.call()
 				
 		#*** convert prior if needed
 		res <- pmle_process_prior( prior , pars )	
@@ -17,42 +17,42 @@ amh <- function( data , nobs , pars , model ,  prior , proposal_sd ,
 		dens <- res$dens				
 		
 		#****							
-		NP <- base::length(pars)
+		NP <- length(pars)
 		if ( is.null(pars_lower)){
-			pars_lower <- base::rep(-Inf, NP)
+			pars_lower <- rep(-Inf, NP)
 		}
 		if ( is.null(pars_upper)){
-			pars_upper <- base::rep(Inf, NP)
+			pars_upper <- rep(Inf, NP)
 		}		
-		acceptance_target <- base::mean( acceptance_bounds )
+		acceptance_target <- mean( acceptance_bounds )
 		
 		#*** object pseudo likelihood estimation
-		pmle_pars <- base::list( pars = pars , posteriorval = -Inf )
+		pmle_pars <- list( pars = pars , posteriorval = -Inf )
 		
 		#*** define objects for acceptance rates
-		acceptance_parameters <- base::matrix( 0 , nrow=NP , ncol=2 )
-		base::rownames(acceptance_parameters) <- base::names(pars)
-		base::colnames(acceptance_parameters) <- base::c("accepted" , "sampled" )
+		acceptance_parameters <- matrix( 0 , nrow=NP , ncol=2 )
+		rownames(acceptance_parameters) <- names(pars)
+		colnames(acceptance_parameters) <- c("accepted" , "sampled" )
 
 		#*** at which iteration refreshing should be made?
-		iter_refresh <- base::seq( 0 , n.burnin, proposal_refresh )
-		LI <- base::length(iter_refresh)
+		iter_refresh <- seq( 0 , n.burnin, proposal_refresh )
+		LI <- length(iter_refresh)
 		proposal_sd_history <- matrix( NA , nrow=LI , ncol=NP )
 		proposal_sd_history[1,] <- proposal_sd
-		base::colnames(proposal_sd_history) <- base::names(pars)
-		base::rownames(proposal_sd_history) <- iter_refresh
-		base::attr(proposal_sd_history,"include") <- 2
+		colnames(proposal_sd_history) <- names(pars)
+		rownames(proposal_sd_history) <- iter_refresh
+		attr(proposal_sd_history,"include") <- 2
 		
 		#*** create object for saving chains
 		n.sims1 <- n.iter - n.burnin 
-		n.sims <- base::min( n.sims , n.sims1 )
+		n.sims <- min( n.sims , n.sims1 )
 		thin0 <- n.sims1 / n.sims
-		thin1 <- base::floor(thin0)
-		iter_thinned <- base::seq(n.iter , n.burnin+1 , - thin1)
+		thin1 <- floor(thin0)
+		iter_thinned <- seq(n.iter , n.burnin+1 , - thin1)
 		iter_thinned <- iter_thinned[ iter_thinned > n.burnin ]
-		NS <- base::length(iter_thinned)
-		pars_chain <- base::matrix( NA , nrow=NS , ncol=NP+1)
-		base::colnames(pars_chain) <- base::c("deviance",names(pars))	
+		NS <- length(iter_thinned)
+		pars_chain <- matrix( NA , nrow=NS , ncol=NP+1)
+		colnames(pars_chain) <- c("deviance",names(pars))	
 		# iter_save <- seq( n.burnin+1 , n.iter )
 		iter_save <- iter_thinned
 		it <- 1
@@ -80,14 +80,14 @@ amh <- function( data , nobs , pars , model ,  prior , proposal_sd ,
 				            proposal_sd ,  acceptance_bounds )	
 				acceptance_parameters <- res0$acceptance_parameters
 				proposal_sd <- res0$proposal_sd
-				hh <- base::attr(proposal_sd_history,"include")
+				hh <- attr(proposal_sd_history,"include")
 				proposal_sd_history[ hh , ] <- proposal_sd
-				base::attr(proposal_sd_history,"include") <- hh + 1
+				attr(proposal_sd_history,"include") <- hh + 1
 			}			
 					
 			#*** print progress
 			if ( it %% print_iter == 0 ){
-				base::cat( base::paste0(" ** Iteration " , it , "\n")  )
+				cat( paste0(" ** Iteration " , it , "\n")  )
 				utils::flush.console()
 			}			
 			it <- it + 1
@@ -96,30 +96,30 @@ amh <- function( data , nobs , pars , model ,  prior , proposal_sd ,
 	
 		#**** create mcmc object
 		mcmcobj <- coda::mcmc( data= pars_chain , 
-		                start = base::min(iter_thinned) , 
-						end = base::max(iter_thinned), 
+		                start = min(iter_thinned) , 
+						end = max(iter_thinned), 
 		                thin = thin1 )
 		#--- include derived parameters in wanted
 		ND <- 0
 		if ( ! is.null(derivedPars) ){
 			mcmcobj <- mcmc_derivedPars( mcmcobj=mcmcobj , derivedPars=derivedPars )		
-			ND <- base::length(derivedPars)
+			ND <- length(derivedPars)
 		}
 						
 		amh_summary <- mcmc_summary(mcmcobj)
 		accrate <- acceptance_parameters[,1] / acceptance_parameters[,2]
-		amh_summary$accrate <- base::c( NA , accrate , base::rep(NA,ND) )
+		amh_summary$accrate <- c( NA , accrate , rep(NA,ND) )
 		
 		#*** evaluate log-likelihood for MAP estimator	
-		parnames <-	base::names(pars)
+		parnames <-	names(pars)
 		pars_MAP <- amh_summary[ 2:(NP+1) , "MAP"]
-		base::names(pars_MAP) <- parnames	
+		names(pars_MAP) <- parnames	
 		res_MAP <- amh_posterior( pars = pars_MAP , model , prior , data)
 		ll <- res_MAP$ll
 
 		#*** evaluate log-likelihood for mean
 		pars_Mean <- amh_summary[ 2:(NP+1) , "Mean"]
-		base::names(pars_Mean) <- parnames	
+		names(pars_Mean) <- parnames	
 		res_Mean <- amh_posterior( pars = pars_Mean , model , prior , data)
 			
 		#*** compare different estimators
@@ -133,13 +133,13 @@ amh <- function( data , nobs , pars , model ,  prior , proposal_sd ,
 										
 		#*** methods
 		coef1 <- amh_summary$MAP[-1]
-		base::names(coef1) <- amh_summary$parameter[-1]		
+		names(coef1) <- amh_summary$parameter[-1]		
 		vcov1 <- stats::var(mcmcobj)[-1,-1]
 		
-		time$end <- base::Sys.time()
+		time$end <- Sys.time()
 		
 		#**** output list
-		res <- base::list( 
+		res <- list( 
 		    pars_chain = pars_chain ,
 			acceptance_parameters = acceptance_parameters ,
 			amh_summary = amh_summary , 
@@ -156,7 +156,7 @@ amh <- function( data , nobs , pars , model ,  prior , proposal_sd ,
 			time=time , CALL = CALL
 					)
 		res$description <- "Adaptive Metropolis Hastings Sampling"				
-		base::class(res) <- "amh"
-		base::return(res)
+		class(res) <- "amh"
+		return(res)
 }
-#################################################################################			
\ No newline at end of file
+#################################################################################			
