@@ -1,10 +1,10 @@
 
 diag2 <- function( vec)
 {
-	if ( base::length(vec) > 1){
-		res <- base::diag(vec)
+	if ( length(vec) > 1){
+		res <- diag(vec)
 	} else {
 		res <- matrix(vec, nrow=1,ncol=1)
 	}
-	base::return(res)
-}
\ No newline at end of file
+	return(res)
+}
