@@ -1,7 +1,7 @@
 
 mlnormal_adjust_numdiff_parameter <- function( h , pars ){
     #** select h parameters according to size of parameters
-    abs_par <- base::abs(pars)       
-    hvec <- h * base::ifelse( abs_par > 1 , abs_par , 1 )
-	base::return(hvec)
-}
\ No newline at end of file
+    abs_par <- abs(pars)       
+    hvec <- h * ifelse( abs_par > 1 , abs_par , 1 )
+	return(hvec)
+}
