@@ -3,11 +3,11 @@
 mlnormal_proc_variance_shortcut_XY_R <- function(y , X , G , freq_id){
 		y0 <- y
 		X0 <- X
-		index_orig <- base::unlist( base::sapply( 1:G , FUN = function(gg){
+		index_orig <- unlist( sapply( 1:G , FUN = function(gg){
 			                freq_id[gg,"start_orig"]:freq_id[gg,"end_orig"] } ) )		
 		X <- X0[ index_orig , ]
 		y <- y0[ index_orig ]	
-		res <- base::list( y=y , X=X)	
-		base::return(res)
+		res <- list( y=y , X=X)	
+		return(res)
 }
-		
\ No newline at end of file
+		
