@@ -3,7 +3,7 @@
 summary.amh <- function( object , digits=3 , file=NULL ,... ){
 
     # open sink
-    CDM::osink( file = file , suffix = paste0( file, "__SUMMARY.Rout") )
+    CDM::osink( file = file , suffix = "__SUMMARY.Rout" )
 
 	cat("-----------------------------------------------------------------\n")
 	d1 <- utils::packageDescription("sirt")
@@ -95,4 +95,4 @@ summary.amh <- function( object , digits=3 , file=NULL ,... ){
     CDM::csink( file = file )		
 	
 	}
-#############################################################	
\ No newline at end of file
+#############################################################	
