@@ -3,7 +3,7 @@
 summary.linking.haberman <- function( object , digits = 3 , file=NULL , ... ){
 
     # open sink
-    CDM::osink( file = file , suffix = paste0( file, "__SUMMARY.Rout") )
+    CDM::osink( file = file , suffix = paste0( "__SUMMARY.Rout") )
 
 	cat("-----------------------------------------------------------------\n")
 	d1 <- utils::packageDescription("sirt")
@@ -71,4 +71,4 @@ summary.linking.haberman <- function( object , digits = 3 , file=NULL , ... ){
 	# close sink
     CDM::csink( file = file )		
 	
-}
\ No newline at end of file
+}
