@@ -9,17 +9,12 @@ summary.lsem <- function( object , file=NULL , digits=3 , ... ){
 	cat("-----------------------------------------------------------------\n")
 	cat("Local Structural Equation Model \n\n")
 		
-    d1 <- utils::packageDescription("sirt")
-	cat( paste( d1$Package , " " , d1$Version , " (" , d1$Date , ")" , sep="") , "\n" )	
-    d1 <- utils::packageDescription("lavaan")
-	cat( paste( d1$Package , " " , d1$Version , " (" , d1$Date , ")" , sep="") , "\n" )	
-    d1 <- utils::packageDescription("lavaan.survey")
-	cat( paste( d1$Package , " " , d1$Version , " (" , d1$Date , ")" , sep="") , "\n" )	
-	
-	
-	cat(paste0("\nFunction 'lsem.estimate', type='" , object$type,"'") , "\n\n")
-	
+	cat( package_version_date("sirt") , "\n" )
+	cat( package_version_date("lavaan") , "\n" )	
+	cat( package_version_date("lavaan.survey") , "\n" )			
 	
+	cat(paste0("\nFunction 'sirt::lsem.estimate', type='" , object$type,"'") , "\n\n")
+		
 	cat("Call:\n", paste(deparse(object$CALL), sep = "\n", collapse = "\n"), 
 				"\n\n", sep = "")		
 	
@@ -75,4 +70,4 @@ summary.lsem <- function( object , file=NULL , digits=3 , ... ){
 	CDM::csink(file)
 	
 	}
-#############################################
\ No newline at end of file
+#############################################
