@@ -3,7 +3,7 @@
 # trace of a matrix
 tracemat <- function(A)
 { 
-    res <- base::sum( base::diag(A) ) 
-	base::return(res)
+    res <- sum( diag(A) ) 
+	return(res)
 } 
-########################################
\ No newline at end of file
+########################################
