@@ -19,7 +19,7 @@ unidim.test.csn <- function( dat , RR=400 , prop.perm=.75 ,
 	for (ss in 1:SS){
 	for (ii in 1:ncol(dat)){
 		iss <- score_index[ss,1]:score_index[ss,2]
-		dat_perm[iss,ii] <- base::sample( dat[iss,ii] )
+		dat_perm[iss,ii] <- sample( dat[iss,ii] )
 					}
 			}
 	score_index <- cbind( score_index , round( score_index[,3] * prop.perm ) )
@@ -34,10 +34,9 @@ unidim.test.csn <- function( dat , RR=400 , prop.perm=.75 ,
 # SEXP score_index_) ;
 # }
     if (progress==1){    cat("|**********|\n")  }
-	res <- .Call( "gooijer_csn_table" , 
+	res <- gooijer_csn_table(
 		        dat , dat_perm , RR=RR , NS=0 , progress , progress_vec ,
-				as.matrix(score_index) ,
-				package="sirt" )
+				as.matrix(score_index)  )
 	res$p <- mean(res$stat < res$stat_perm)
 	res$H0_quantiles <- stats::quantile(res$stat_perm , c(.05 , .25 , .50 , .75 , .95 , .99 , .999 ) )
 	if ( progress == 1 ){
@@ -46,4 +45,4 @@ unidim.test.csn <- function( dat , RR=400 , prop.perm=.75 ,
 		}
 	return(res)
 	}
-#############################################################
\ No newline at end of file
+#############################################################
