@@ -1,8 +1,8 @@
 
 weighted_rowMeans <- function( mat , wgt=NULL){
 	wgt <- weighted_stats_extend_wgt( wgt=wgt , mat=mat )
-	mat1 <- base::rowSums( mat * wgt , na.rm=TRUE) 
-	mat2 <- base::rowSums( wgt , na.rm=TRUE) 
+	mat1 <- rowSums( mat * wgt , na.rm=TRUE) 
+	mat2 <- rowSums( wgt , na.rm=TRUE) 
 	mat1 <- mat1 / mat2
-	base::return(mat1)
-}
\ No newline at end of file
+	return(mat1)
+}
