@@ -2,10 +2,10 @@
 #########################################################################
 xxirt_partable_extract_freeParameters <- function( partable ){
 		partable <- partable[ partable$est , ]
-		partable <- partable[ base::order(partable$parindex) , ]
-		partable <- partable[ ! base::duplicated( partable$parindex) , ]
+		partable <- partable[ order(partable$parindex) , ]
+		partable <- partable[ ! duplicated( partable$parindex) , ]
 		x <- partable$value
-		base::names(x) <- partable$parlabel
-		base::return(x)
+		names(x) <- partable$parlabel
+		return(x)
 }
-#########################################################################
\ No newline at end of file
+#########################################################################
