@@ -1,20 +1,10 @@
+// [[Rcpp::depends(RcppArmadillo)]]
 
-// includes from the plugin
-
-// #include <Rcpp.h>
 #include <RcppArmadillo.h>
-
-#ifndef BEGIN_RCPP
-#define BEGIN_RCPP
-#endif
-
-#ifndef END_RCPP
-#define END_RCPP
-#endif
+#include <Rcpp.h>
 
 using namespace Rcpp;
 
-
 // user includes
 
 
@@ -27,25 +17,14 @@ using namespace Rcpp;
 
 
 
-
-// declarations
-extern "C" {
-SEXP rm_arraymult1( SEXP A, SEXP dimA, SEXP B, SEXP dimB) ;
-}
-
-// definition
-
-SEXP rm_arraymult1( SEXP A, SEXP dimA, SEXP B, SEXP dimB ){
-BEGIN_RCPP
-// define input and arrays
-      // array A
-      Rcpp::NumericMatrix AA(A);
-      Rcpp::IntegerVector dimAA(dimA);
-      // array B
-      Rcpp::NumericMatrix BB(B);
-      Rcpp::IntegerVector dimBB(dimB);
-      Rcpp::NumericMatrix CC( dimAA[0]*dimAA[1] , dimBB[2] ) ;
-      
+///********************************************************************
+///** probs_pcm_nogroups_C
+// [[Rcpp::export]]
+Rcpp::NumericMatrix rm_arraymult1( Rcpp::NumericMatrix AA, 
+	Rcpp::NumericVector dimAA, Rcpp::NumericMatrix BB, 
+	Rcpp::NumericVector dimBB ){
+           
+      Rcpp::NumericMatrix CC( dimAA[0]*dimAA[1] , dimBB[2] ) ; 
       int a1 = dimAA[0];
       int a2 = dimAA[1];
       int a3 = dimAA[2];
@@ -64,11 +43,11 @@ BEGIN_RCPP
                   }
       
       // output
-      return( wrap(CC) );
-END_RCPP
+      return CC;
 }
 
 
+
 //**********************************************************************
 ////////////////////////////////////////////////////////////////////////
 // calculation posterior distribution
@@ -78,23 +57,13 @@ END_RCPP
 
 
 
-// declarations
-extern "C" {
-SEXP RM_CALCPOST( SEXP dat2, SEXP dat2resp, SEXP probs, SEXP K) ;
-}
-
-// definition
-
-SEXP RM_CALCPOST( SEXP dat2, SEXP dat2resp, SEXP probs, SEXP K ){
-BEGIN_RCPP
-  
-     /////////////////////////////////////  
-     // INPUT  
-     Rcpp::NumericMatrix DAT2(dat2);  
-     Rcpp::NumericMatrix DAT2RESP(dat2resp);  
-     Rcpp::NumericMatrix PROBS(probs);  
-     Rcpp::NumericVector KK(K);  
-       
+///********************************************************************
+///** RM_CALCPOST
+// [[Rcpp::export]]
+Rcpp::List RM_CALCPOST( Rcpp::NumericMatrix DAT2, 
+	Rcpp::NumericMatrix DAT2RESP, Rcpp::NumericMatrix PROBS, 
+	Rcpp::NumericVector KK ){
+         
      int N=DAT2.nrow();  
      int I=DAT2.ncol();  
      int TP=PROBS.ncol();  
@@ -102,7 +71,7 @@ BEGIN_RCPP
        
      //*****  
      // calculate individual likelihood  
-     NumericMatrix fyiqk (N,TP) ;  
+     Rcpp::NumericMatrix fyiqk (N,TP) ;  
      fyiqk.fill(1);  
      for (int ii=0;ii<I;++ii){      
      for (int nn=0;nn<N;++nn){  
@@ -113,23 +82,18 @@ BEGIN_RCPP
                      }  
                  }  
              }  
-       
-     			  
+       		  
      ///////////////////////////////////////////////////////  
      ///////////// O U T P U T   ///////////////////////////  
      return Rcpp::List::create(
             Rcpp::_["fyiqk"] = fyiqk 
-                );   
-     	  
-       
-     /// print output on R console  
-     //		Rcpp::Rcout << "hier:" << std::endl << nn << std::endl;					
-END_RCPP
+                );  		
 }
 
 
 
 
+
 //**********************************************************************
 ////////////////////////////////////////////////////////////////////////
 /// calculation of probabilities
@@ -138,38 +102,29 @@ END_RCPP
 //**********************************************************************
 
 
-// declarations
-extern "C" {
-SEXP rm_probraterfct1( SEXP crater, SEXP drater, SEXP dimA, SEXP B, SEXP dimB) ;
-}
+///********************************************************************
+///** rm_probraterfct1
+// [[Rcpp::export]]
+Rcpp::List rm_probraterfct1( Rcpp::NumericMatrix CRA, 
+	Rcpp::NumericVector DRA , Rcpp::IntegerVector dimAA, 
+	Rcpp::NumericMatrix BB, Rcpp::IntegerVector dimBB ){
 
-// definition
-
-SEXP rm_probraterfct1( SEXP crater, SEXP drater, SEXP dimA, SEXP B, SEXP dimB ){
-BEGIN_RCPP
-
-      //////////////////////////////////////////
-      //////// I N P U T ///////////////////////
-      // c.rater
-      Rcpp::NumericMatrix CRA(crater);
-      // d.rater
-      Rcpp::NumericVector DRA(drater) ;
       int K = CRA.ncol();
       int I = CRA.nrow();
       
       // define input and arrays
       // dimA (I,K+1,K+1)
-      Rcpp::IntegerVector dimAA(dimA);
+      // Rcpp::IntegerVector dimAA(dimA);
       // array B (I,K+1,TP)
-      Rcpp::NumericMatrix BB(B);
-      Rcpp::IntegerVector dimBB(dimB);
+      // Rcpp::NumericMatrix BB(B);
+      // Rcpp::IntegerVector dimBB(dimB);
       Rcpp::NumericMatrix CC( dimAA[0]*dimAA[1] , dimBB[2] ) ;
       
       ////////////////////////////////////////////
       
       //*********************
       // create h1 matrix
-      NumericMatrix h1(I*(K+1),K) ;
+      Rcpp::NumericMatrix h1(I*(K+1),K) ;
       int nrh1 = h1.nrow();
       
       for (int kk=0;kk<(K+1);++kk){
@@ -184,8 +139,8 @@ BEGIN_RCPP
       // compute logistic distribution
       // for (int kk=0; kk<K; ++kk){
       for (int kk=0;kk<K;++kk){
-          NumericVector inpv =h1(_,kk) ;
-          NumericVector res0=plogis(inpv) ;
+          Rcpp::NumericVector inpv =h1(_,kk) ;
+          Rcpp::NumericVector res0=plogis(inpv) ;
           for (int ii=0;ii<nrh1;++ii){
               h1(ii,kk) = res0[ii] ;
                                }
@@ -195,7 +150,7 @@ BEGIN_RCPP
       // compute matrix with rater probabilities  
       
       // P(X=0) ;                
-      NumericMatrix PRA(I*(K+1),K+1) ;         
+      Rcpp::NumericMatrix PRA(I*(K+1),K+1) ;         
       for (int jj=0;jj<(K+1);++jj){                
           for (int ii=0;ii<I;++ii){
               PRA(ii,jj) = h1(ii+I*jj, 0 ) ;
@@ -219,9 +174,7 @@ BEGIN_RCPP
       
       //**************************
       // multiplication 
-      
-      NumericMatrix AA=PRA ;             
-                  
+      Rcpp::NumericMatrix AA=PRA ;                   
       int a1 = dimAA[0];
       int a2 = dimAA[1];
       int a3 = dimAA[2];
@@ -246,13 +199,13 @@ BEGIN_RCPP
          Rcpp::_["probtotal"] = CC
                     );            
                   
-      //return( wrap(res0) );
-END_RCPP
 }
 
 
 
 
+
+
 //********************************************************************
 //********************************************************************
 //********************************************************************
@@ -261,35 +214,16 @@ END_RCPP
 //********************************************************************
 //********************************************************************
 
-// declarations
-extern "C" {
-SEXP rm_facets_calcprobs_cpp( SEXP b_item_, SEXP b_rater_, SEXP Qmatrix_, 
-	SEXP tau_item_, SEXP K_, SEXP I_, SEXP TP_, SEXP a_item_, SEXP a_rater_, 
-	SEXP item_index_, SEXP rater_index_, SEXP theta_k_ ) ;
-}
+///********************************************************************
+///** rm_facets_calcprobs_cpp
+// [[Rcpp::export]]
+Rcpp::NumericMatrix rm_facets_calcprobs_cpp( Rcpp::NumericVector b_item, 
+	Rcpp::NumericVector b_rater, Rcpp::NumericMatrix Qmatrix, 
+	Rcpp::NumericMatrix tau_item, int K, int I, int TP, 
+	Rcpp::NumericVector a_item, Rcpp::NumericVector a_rater, 
+	Rcpp::NumericVector item_index, Rcpp::NumericVector rater_index, 
+	Rcpp::NumericVector theta_k ){
 
-// definition
-
-SEXP rm_facets_calcprobs_cpp( SEXP b_item_, SEXP b_rater_, SEXP Qmatrix_, 
-	SEXP tau_item_, SEXP K_, SEXP I_, SEXP TP_, SEXP a_item_, SEXP a_rater_, 
-	SEXP item_index_, SEXP rater_index_, SEXP theta_k_ ){
-BEGIN_RCPP
-  
-     /////////////////////////////////////  
-     // INPUT  
-     Rcpp::NumericVector b_item(b_item_);  
-     Rcpp::NumericVector b_rater(b_rater_);   
-     Rcpp::NumericMatrix Qmatrix(Qmatrix_);  
-     Rcpp::NumericMatrix tau_item(tau_item_);  
-     // int VV = as<int>(VV_);  
-     int K = as<int>(K_);  
-     int I = as<int>(I_);  
-     int TP = as<int>(TP_);  
-     Rcpp::NumericVector a_item(a_item_);  
-     Rcpp::NumericVector a_rater(a_rater_);   
-     Rcpp::NumericVector item_index(item_index_);   
-     Rcpp::NumericVector rater_index(rater_index_);  
-     Rcpp::NumericVector theta_k(theta_k_);  
      // int RR = as<int>(RR_);  
      //    probs <- .rm.facets.calcprobs( b.item , b.rater , Qmatrix , tau.item ,  
      //           VV , K , I , TP , a.item , a.rater , item.index , rater.index ,  
@@ -330,10 +264,7 @@ BEGIN_RCPP
      //        l0 <- l0 + outer( a * Qmatrix[ , kk] , theta.k )  
      //        probs[,kk+1,] <- l0  
      //                }  
-       
      // probs(ii , kk , tt ) ~ probs( ii , kk + tt * (K+1) )  
-       
-       
      double tmp1 = 0 ;   
        
      for (int tt=0;tt<TP;tt++){  
@@ -350,24 +281,14 @@ BEGIN_RCPP
      		}   // end ii  
      	} // end tt  
        
-     return wrap( probs ) ;   
-     	  
-     ///////////////////////////////////////  
-     /// OUTPUT                  
-       
-     // return List::create(  
-     //	        _["b"] = b ,  
-     //		_["a"]= a ,  
-     //		_["probs"] = probs  
-     //			) ;  
-     //	   _["matrk"]=MATRK  , _["indexmatr"]=INDEXMATR ) ;     
-     // return List::create(_["yM"]=YM , _["wM"]=WM ) ;     
-     
-END_RCPP
+     return probs ;       	  
 }
 
 
 
+
+
+
 //**********************************************************************
 ////////////////////////////////////////////////////////////////////////
 /// SMIRT_CALCPOST
@@ -375,26 +296,14 @@ END_RCPP
 ////////////////////////////////////////////////////////////////////////
 //**********************************************************************
 
-
-// declarations
-extern "C" {
-SEXP SMIRT_CALCPOST( SEXP dat2, SEXP dat2resp, SEXP probs, SEXP dat2ind, SEXP pik, SEXP K) ;
-}
-
-// definition
-
-SEXP SMIRT_CALCPOST( SEXP dat2, SEXP dat2resp, SEXP probs, SEXP dat2ind, SEXP pik, SEXP K ){
-BEGIN_RCPP
-  
-     /////////////////////////////////////  
-     // INPUT  
-     Rcpp::IntegerMatrix DAT2(dat2);  
-     Rcpp::IntegerMatrix DAT2RESP(dat2resp);  
-     Rcpp::NumericMatrix PROBS(probs);  
-     Rcpp::NumericMatrix DAT2IND(dat2ind);  
-     Rcpp::NumericVector PIK(pik);  
-     Rcpp::NumericVector KK1(K) ;  
-       
+///********************************************************************
+///** SMIRT_CALCPOST
+// [[Rcpp::export]]
+Rcpp::List SMIRT_CALCPOST( Rcpp::IntegerMatrix DAT2, 
+	Rcpp::IntegerMatrix DAT2RESP, Rcpp::NumericMatrix PROBS, 
+	Rcpp::NumericMatrix DAT2IND, Rcpp::NumericVector PIK, 
+	Rcpp::NumericVector KK1 ){
+         
      int N=DAT2.nrow();  
      int I=DAT2.ncol();  
      int TP=PROBS.ncol();  
@@ -402,7 +311,7 @@ BEGIN_RCPP
        
      //*****  
      // calculate individual likelihood  
-     NumericMatrix fyiqk (N,TP) ;  
+     Rcpp::NumericMatrix fyiqk (N,TP) ;  
      fyiqk.fill(1);  
      for (int ii=0;ii<I;++ii){      
      for (int nn=0;nn<N;++nn){  
@@ -416,7 +325,7 @@ BEGIN_RCPP
        
      //****  
      // calculate posterior	  
-     NumericMatrix fqkyi (N,TP) ;  
+     Rcpp::NumericMatrix fqkyi (N,TP) ;  
      for (int nn=0;nn<N;++nn){  
      	double total = 0; 	  
      	for (int tt=0;tt<TP;++tt){  
@@ -437,8 +346,8 @@ BEGIN_RCPP
      	PIK[tt] = PIK[tt] / N ;   
      			}  
        
-     NumericMatrix nik (TP, I*(KK+1)) ;  
-     NumericMatrix NIK (TP, I) ;			  
+     Rcpp::NumericMatrix nik (TP, I*(KK+1)) ;  
+     Rcpp::NumericMatrix NIK (TP, I) ;			  
      for (int tt=0;tt<TP;++tt){  
      for (int ii=0; ii < I ; ++ii){  
      for (int kk=0;kk<KK+1;++kk){			  
@@ -461,12 +370,10 @@ BEGIN_RCPP
         Rcpp::_["N.ik"]=NIK 
                  );   
      	  
-       
-     /// print output on R console  
-     //		Rcpp::Rcout << "hier:" << std::endl << nn << std::endl;					
-END_RCPP
 }
 
+
+
 //**********************************************************************
 ////////////////////////////////////////////////////////////////////////
 /// SMIRT_CALCPROB_COMP
@@ -474,35 +381,22 @@ END_RCPP
 ////////////////////////////////////////////////////////////////////////
 //**********************************************************************
 
-// declarations
-extern "C" {
-SEXP SMIRT_CALCPROB_COMP( SEXP a, SEXP b, SEXP Q, SEXP thetak, SEXP cc, SEXP dd) ;
-}
-
-// definition
-
-SEXP SMIRT_CALCPROB_COMP( SEXP a, SEXP b, SEXP Q, SEXP thetak, SEXP cc, SEXP dd ){
-BEGIN_RCPP
-  
-
-    /////////////////////////////////////
-    // INPUT
-    Rcpp::NumericMatrix A(a);
-    Rcpp::NumericVector B(b);
-    Rcpp::NumericMatrix QQ(Q);
-    Rcpp::NumericMatrix THETA(thetak);
-    Rcpp::NumericVector CC(cc);
-    Rcpp::NumericVector DD(dd);
-
+///********************************************************************
+///** SMIRT_CALCPROB_COMP
+// [[Rcpp::export]]
+Rcpp::NumericMatrix SMIRT_CALCPROB_COMP( Rcpp::NumericMatrix A, 
+	Rcpp::NumericVector B, Rcpp::NumericMatrix QQ, 
+	Rcpp::NumericMatrix THETA, Rcpp::NumericVector CC, 
+	Rcpp::NumericVector DD ){
+ 
     int I=A.nrow();
     int D=A.ncol();
     int TP=THETA.nrow();
 
     // create matrix of probabilities
-    NumericMatrix prob (I,TP) ;
+    Rcpp::NumericMatrix prob (I,TP) ;
     prob.fill(1);
-
-    NumericVector yy (TP);
+    Rcpp::NumericVector yy (TP);
 
     for (int ii=0;ii<I;++ii){
             for (int tt=0; tt<TP; ++tt){
@@ -511,7 +405,7 @@ BEGIN_RCPP
                    yy[tt] += A(ii,dd)*QQ(ii,dd)*THETA(tt,dd)  ;
                     } // end dd 
                         }   // end tt
-            NumericVector p1=plogis(yy) ;
+            Rcpp::NumericVector p1=plogis(yy) ;
             for (int tt=0; tt<TP; ++tt){            
                 prob(ii,tt)= p1[tt] ;
                   }  // end tt
@@ -526,13 +420,11 @@ BEGIN_RCPP
         
     ///////////////////////////////////////
     /// OUTPUT    
-    return(wrap(prob)) ;             
-    // return( wrap(prob) );
-         
-END_RCPP
+    return prob ;             
 }
 
 
+
 //**********************************************************************
 ////////////////////////////////////////////////////////////////////////
 /// SMIRT_CALCPROB_NONCOMP
@@ -540,34 +432,23 @@ END_RCPP
 ////////////////////////////////////////////////////////////////////////
 //**********************************************************************
 
-// declarations
-extern "C" {
-SEXP SMIRT_CALCPROB_NONCOMP( SEXP a, SEXP b, SEXP Q, SEXP thetak, SEXP cc, SEXP dd) ;
-}
 
-// definition
-
-SEXP SMIRT_CALCPROB_NONCOMP( SEXP a, SEXP b, SEXP Q, SEXP thetak, SEXP cc, SEXP dd ){
-BEGIN_RCPP
-  
-     /////////////////////////////////////  
-     // INPUT  
-     Rcpp::NumericMatrix A(a);  
-     Rcpp::NumericMatrix B(b);  
-     Rcpp::NumericMatrix QQ(Q);  
-     Rcpp::NumericMatrix THETA(thetak);  
-     Rcpp::NumericVector CC(cc);  
-     Rcpp::NumericVector DD(dd);  
-       
+///********************************************************************
+///** SMIRT_CALCPROB_NONCOMP
+// [[Rcpp::export]]
+Rcpp::NumericMatrix SMIRT_CALCPROB_NONCOMP( Rcpp::NumericMatrix A, 
+	Rcpp::NumericMatrix B, Rcpp::NumericMatrix QQ, 
+	Rcpp::NumericMatrix THETA, Rcpp::NumericVector CC, 
+	Rcpp::NumericVector DD ){
+        
      int I=A.nrow();  
      int D=A.ncol();  
      int TP=THETA.nrow();  
        
      // create matrix of probabilities  
-     NumericMatrix prob (I,TP) ;  
+     Rcpp::NumericMatrix prob (I,TP) ;  
      prob.fill(1);  
-       
-     NumericVector yy (TP);  
+     Rcpp::NumericVector yy (TP);  
        
      for (int ii=0;ii<I;++ii){  
      for (int dd=0;dd<D;++dd){  
@@ -575,7 +456,7 @@ BEGIN_RCPP
              for (int tt=0; tt<TP; ++tt){  
                     yy[tt] =  A(ii,dd)*QQ(ii,dd)*THETA(tt,dd)-B(ii,dd)   ;  
                          }   // end tt  
-             NumericVector p1=plogis(yy) ;  
+             Rcpp::NumericVector p1=plogis(yy) ;  
              for (int tt=0; tt<TP; ++tt){              
                  prob(ii,tt)=prob(ii,tt)*p1[tt] ;  
                    }  // end tt  
@@ -592,10 +473,7 @@ BEGIN_RCPP
            
      ///////////////////////////////////////  
      /// OUTPUT      
-     return(wrap(prob)) ;               
-     // return( wrap(prob) );  
-     
-END_RCPP
+     return prob ;               
 }
 
 
@@ -607,42 +485,25 @@ END_RCPP
 ////////////////////////////////////////////////////////////////////////
 //**********************************************************************
 
-// declarations
-extern "C" {
-SEXP SMIRT_CALCPROB_PARTCOMP( SEXP a, SEXP b, SEXP Q, SEXP thetak, SEXP cc, SEXP dd ,
-	SEXP mui ) ;
-}
-
-// definition
-
-SEXP SMIRT_CALCPROB_PARTCOMP( SEXP a, SEXP b, SEXP Q, SEXP thetak, SEXP cc, SEXP dd ,
-	SEXP mui ){
-BEGIN_RCPP
-  
-     /////////////////////////////////////  
-     // INPUT  
-     Rcpp::NumericMatrix A(a);  
-     Rcpp::NumericMatrix B(b);  
-     Rcpp::NumericMatrix QQ(Q);  
-     Rcpp::NumericMatrix THETA(thetak);  
-     Rcpp::NumericVector CC(cc);  
-     Rcpp::NumericVector DD(dd);  
-     Rcpp::NumericVector MUI(mui) ;
+///********************************************************************
+///** SMIRT_CALCPROB_PARTCOMP
+// [[Rcpp::export]]
+Rcpp::NumericMatrix SMIRT_CALCPROB_PARTCOMP( Rcpp::NumericMatrix A, 
+	Rcpp::NumericMatrix B, Rcpp::NumericMatrix QQ, 
+	Rcpp::NumericMatrix THETA, Rcpp::NumericVector CC, 
+	Rcpp::NumericVector DD , Rcpp::NumericVector MUI ){
        
      int I=A.nrow();  
      int D=A.ncol();  
-     int TP=THETA.nrow();  
-               
+     int TP=THETA.nrow();         
      // create matrix of probabilities  
-     NumericMatrix prob (I,TP) ;  
+     Rcpp::NumericMatrix prob (I,TP) ;  
      prob.fill(1);  
-       
-     NumericVector yy1 (1);  
-     NumericVector yy2 (1); 
-     NumericVector yy3 (1);
+     Rcpp::NumericVector yy1 (1);  
+     Rcpp::NumericVector yy2 (1); 
+     Rcpp::NumericVector yy3 (1);
      double tmp1 ;
      
-     
      for (int ii=0;ii<I;++ii){  
      for (int tt=0; tt<TP; ++tt){
      	    yy1[0] = 0 ; 
@@ -667,48 +528,30 @@ BEGIN_RCPP
            
      ///////////////////////////////////////  
      /// OUTPUT      
-     return(wrap(prob)) ;               
-     // return( wrap(prob) );  
-     
-END_RCPP
+     return prob ;               
 }
 
 
+
 /////////////////////////////////////////////////////////////
 /// rasch.mml2 : calculate counts
 
-// user includes
+///********************************************************************
+///** MML2_RASCHTYPE_COUNTS
+// [[Rcpp::export]]
+Rcpp::List MML2_RASCHTYPE_COUNTS( Rcpp::NumericMatrix DAT2, 
+	Rcpp::NumericMatrix DAT2RESP, Rcpp::NumericVector DAT1, 
+	Rcpp::NumericMatrix FQKYI, Rcpp::NumericVector PIK, 
+	Rcpp::NumericMatrix FYIQK ){
 
-// declarations
-extern "C" {
-SEXP MML2_RASCHTYPE_COUNTS( SEXP dat2, SEXP dat2resp, SEXP dat1, SEXP fqkyi, 
-	SEXP pik, SEXP fyiqk) ;
-}
-
-// definition
-
-SEXP MML2_RASCHTYPE_COUNTS( SEXP dat2, SEXP dat2resp, SEXP dat1, SEXP fqkyi, 
-	SEXP pik, SEXP fyiqk ){
-BEGIN_RCPP
-  
-     /////////////////////////////////////  
-     // INPUT  
-     Rcpp::NumericMatrix DAT2(dat2);  
-     Rcpp::NumericMatrix DAT2RESP(dat2resp);  
-     Rcpp::NumericVector DAT1(dat1) ;  
-     Rcpp::NumericMatrix FQKYI(fqkyi) ;  
-     Rcpp::NumericVector PIK (pik) ;   
-     Rcpp::NumericMatrix FYIQK(fyiqk) ;  
-       
      int N=DAT2.nrow();  
      int I=DAT2.ncol();  
      int TP=FQKYI.ncol();  
        
      //**********************************  
      // calculate total counts n.k  
-     NumericVector NK (TP);  
+     Rcpp::NumericVector NK (TP);  
      NK.fill(0);  
-       
      for (int tt=0;tt<TP;++tt){      
          for (int nn=0;nn<N;++nn){  
      //        NK[tt] = NK[tt] + FQKYI(nn,tt)*DAT1[nn] ;   
@@ -718,8 +561,8 @@ BEGIN_RCPP
        
      //**********************************  
      // calculate n.jk and r.jk  
-     NumericMatrix NJK (I,TP) ;  
-     NumericMatrix RJK (I,TP) ;  
+     Rcpp::NumericMatrix NJK (I,TP) ;  
+     Rcpp::NumericMatrix RJK (I,TP) ;  
      NJK.fill(0) ;                   
      RJK.fill(0) ;    
                        
@@ -736,12 +579,9 @@ BEGIN_RCPP
        
      //*****************  
      // calculate loglikelihood  
-       
      double LL=0;  
-       
      //        ll[gg] <- sum( dat1[group==gg,2] * log( rowSums( f.yi.qk[group==gg,] *   
      //					outer( rep(1,nrow(f.yi.qk[group==gg,])) , pi.k[,gg] ) ) ) )  
-       
      for (int nn=0;nn<N;++nn){  
          double total = 0; 	  
          for (int tt=0;tt<TP;++tt){  
@@ -749,8 +589,7 @@ BEGIN_RCPP
                              } // end tt  
          LL += log( total )*DAT1[nn] ;  
                  }  // end nn  
-                           
-                           
+                                                 
      ///////////////////////////////////////////////////////  
      ///////////// O U T P U T   ///////////////////////////  
      return Rcpp::List::create(
@@ -759,11 +598,6 @@ BEGIN_RCPP
          Rcpp::_["rjk"] = RJK , 
          Rcpp::_["ll"] = LL 
                  );   
-     	  
-       
-     /// print output on R console  
-     //		Rcpp::Rcout << "hier:" << std::endl << nn << std::endl;					
-END_RCPP
 }
 
 
@@ -772,23 +606,11 @@ END_RCPP
 //////////////////////////////////////////////////////////////////
 /// rasch.mml2 - calculation of posterior distribution
 
-
-
-// declarations
-extern "C" {
-SEXP MML2_CALCPOST_V1( SEXP dat2, SEXP dat2resp, SEXP probs) ;
-}
-
-// definition
-
-SEXP MML2_CALCPOST_V1( SEXP dat2, SEXP dat2resp, SEXP probs ){
-BEGIN_RCPP
-  
-     /////////////////////////////////////  
-     // INPUT  
-     Rcpp::NumericMatrix DAT2(dat2);  
-     Rcpp::NumericMatrix DAT2RESP(dat2resp);  
-     Rcpp::NumericMatrix PROBS(probs);  
+///********************************************************************
+///** MML2_CALCPOST_V1
+// [[Rcpp::export]]
+Rcpp::List MML2_CALCPOST_V1( Rcpp::NumericMatrix DAT2, 
+	Rcpp::NumericMatrix DAT2RESP, Rcpp::NumericMatrix PROBS ){
        
      int N=DAT2.nrow();  
      int I=DAT2.ncol();  
@@ -796,7 +618,7 @@ BEGIN_RCPP
        
      //*****  
      // calculate individual likelihood  
-     NumericMatrix fyiqk (N,TP) ;  
+     Rcpp::NumericMatrix fyiqk (N,TP) ;  
      fyiqk.fill(1);  
      for (int ii=0;ii<I;++ii){      
      for (int nn=0;nn<N;++nn){  
@@ -807,49 +629,33 @@ BEGIN_RCPP
                      }  
                  }  
              }  
-       
-     			  
+        			  
      ///////////////////////////////////////////////////////  
      ///////////// O U T P U T   ///////////////////////////  
      return Rcpp::List::create(
        Rcpp::_["fyiqk"] = fyiqk 
                    );   
-     	  
-       
-     /// print output on R console  
-     //		Rcpp::Rcout << "hier:" << std::endl << nn << std::endl;					
-END_RCPP
+
 }
 
 
 
+
 //////////////////////////////////////////////////////////////////
 /// rasch.mml2 - calculation of posterior distribution (V2)
 
-
-// declarations
-extern "C" {
-SEXP MML2_CALCPOST_V2( SEXP dat2, SEXP dat2resp, SEXP probs) ;
-}
-
-// definition
-
-SEXP MML2_CALCPOST_V2( SEXP dat2, SEXP dat2resp, SEXP probs ){
-BEGIN_RCPP
-  
-     /////////////////////////////////////  
-     // INPUT  
-     Rcpp::NumericMatrix DAT2(dat2);  
-     Rcpp::NumericMatrix DAT2RESP(dat2resp);  
-     Rcpp::NumericMatrix PROBS(probs);  
+///********************************************************************
+///** MML2_CALCPOST_V2
+// [[Rcpp::export]]
+Rcpp::List MML2_CALCPOST_V2( Rcpp::NumericMatrix DAT2, 
+	Rcpp::NumericMatrix DAT2RESP, Rcpp::NumericMatrix PROBS ){
        
      int N=DAT2.nrow();  
      int I=DAT2.ncol();  
      int TP=PROBS.ncol();  
-       
      //*****  
      // calculate individual likelihood  
-     NumericMatrix fyiqk (N,TP) ;  
+     Rcpp::NumericMatrix fyiqk (N,TP) ;  
      fyiqk.fill(1);  
      for (int ii=0;ii<I;++ii){      
      for (int nn=0;nn<N;++nn){  
@@ -859,25 +665,19 @@ BEGIN_RCPP
 	if ( ( DAT2(nn,ii) < 1 ) & ( DAT2(nn,ii) > 0 ) ){
              fyiqk(nn,tt) = fyiqk(nn,tt) * pow( PROBS(2*ii+1,tt),DAT2(nn,ii) )*
                 	pow( PROBS( 2*ii  , tt ) , 1 - DAT2(nn,ii) ) ;
-                		} else {
+         } else {
              fyiqk(nn,tt) = fyiqk(nn,tt) * PROBS( 2*ii + DAT2(nn,ii) , tt ) ;                			
                 		}
                          }  
                      }  
                  }  
              }  
-       
-     			  
+         
      ///////////////////////////////////////////////////////  
      ///////////// O U T P U T   ///////////////////////////  
      return Rcpp::List::create(
         Rcpp::_["fyiqk"] = fyiqk 
-           );   
-     	  
-       
-     /// print output on R console  
-     //		Rcpp::Rcout << "hier:" << std::endl << nn << std::endl;					
-END_RCPP
+           );   				
 }
 
 
@@ -888,29 +688,18 @@ END_RCPP
 /// fuzzy log likelihood in the belief function framework
 
 
-// declarations
-extern "C" {
-SEXP MML2_CALCPOST_V3( SEXP dat2, SEXP dat2resp, SEXP probs) ;
-}
-
-// definition
-
-SEXP MML2_CALCPOST_V3( SEXP dat2, SEXP dat2resp, SEXP probs ){
-BEGIN_RCPP
-  
-     /////////////////////////////////////  
-     // INPUT  
-     Rcpp::NumericMatrix DAT2(dat2);  
-     Rcpp::NumericMatrix DAT2RESP(dat2resp);  
-     Rcpp::NumericMatrix PROBS(probs);  
+///********************************************************************
+///** MML2_CALCPOST_V3
+// [[Rcpp::export]]
+Rcpp::List MML2_CALCPOST_V3( Rcpp::NumericMatrix DAT2,
+	Rcpp::NumericMatrix DAT2RESP, Rcpp::NumericMatrix PROBS ){
        
      int N=DAT2.nrow();  
      int I=DAT2.ncol();  
-     int TP=PROBS.ncol();  
-       
+     int TP=PROBS.ncol();       
      //*****  
      // calculate individual likelihood  
-     NumericMatrix fyiqk (N,TP) ;  
+     Rcpp::NumericMatrix fyiqk (N,TP) ;  
      fyiqk.fill(1);  
      for (int ii=0;ii<I;++ii){      
      for (int nn=0;nn<N;++nn){  
@@ -927,18 +716,13 @@ BEGIN_RCPP
                      }  
                  }  
              }  
-       
-     			  
+            			  
      ///////////////////////////////////////////////////////  
      ///////////// O U T P U T   ///////////////////////////  
      return Rcpp::List::create(
          Rcpp::_["fyiqk"] = fyiqk 
                         );   
      	  
-       
-     /// print output on R console  
-     //		Rcpp::Rcout << "hier:" << std::endl << nn << std::endl;					
-END_RCPP
 }
 
 
@@ -946,3 +730,6 @@ END_RCPP
 
 
 
+
+
+
